inline void  Log::off()
{
    setActive(OFF);
}
